pub fn compress_kmers_no_exts<K: Kmer + Send + Sync, D: Clone + Debug + Send + Sync + SummaryData<DI>, DI, S: CompressionSpec<D> + Send + Sync>(
stranded: bool,
spec: &S,
kmer_exts: &[(K, D)],
) -> BaseGraph<K, D>Expand description
Build graph from a set of kmers with unknown extensions by finding the extensions on the fly.